Struct Anchor
pub struct Anchor(/* private fields */);wayland and Linux only.Expand description
Specifies which edges and corners a layer should be placed at in the anchor rectangle.
A combination of two orthogonal edges will cause the layer’s anchor point to be the intersection of
the edges. For example Anchor::TOP and Anchor::LEFT will result in an anchor point in the top
left of the anchor rectangle.
Implementations
impl Anchor
impl Anchor
pub const TOP: Anchor
Available on crate features cctk and winit only.
pub const TOP: Anchor
cctk and winit only.Top edge of the anchor rectangle.
pub const BOTTOM: Anchor
Available on crate features cctk and winit only.
pub const BOTTOM: Anchor
cctk and winit only.The bottom edge of the anchor rectangle.
impl Anchor
impl Anchor
pub const fn empty() -> Anchor
Available on crate features cctk and winit only.
pub const fn empty() -> Anchor
cctk and winit only.Get a flags value with all bits unset.
pub const fn all() -> Anchor
Available on crate features cctk and winit only.
pub const fn all() -> Anchor
cctk and winit only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate features cctk and winit only.
pub const fn bits(&self) -> u32
cctk and winit only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Anchor>
Available on crate features cctk and winit only.
pub const fn from_bits(bits: u32) -> Option<Anchor>
cctk and winit only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Anchor
Available on crate features cctk and winit only.
pub const fn from_bits_truncate(bits: u32) -> Anchor
cctk and winit only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Anchor
Available on crate features cctk and winit only.
pub const fn from_bits_retain(bits: u32) -> Anchor
cctk and winit only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Anchor>
Available on crate features cctk and winit only.
pub fn from_name(name: &str) -> Option<Anchor>
cctk and winit only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate features cctk and winit only.
pub const fn is_empty(&self) -> bool
cctk and winit only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate features cctk and winit only.
pub const fn is_all(&self) -> bool
cctk and winit only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: Anchor) -> bool
Available on crate features cctk and winit only.
pub const fn intersects(&self, other: Anchor) -> bool
cctk and winit only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Anchor) -> bool
Available on crate features cctk and winit only.
pub const fn contains(&self, other: Anchor) -> bool
cctk and winit only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: Anchor)
Available on crate features cctk and winit only.
pub fn insert(&mut self, other: Anchor)
cctk and winit only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: Anchor)
Available on crate features cctk and winit only.
pub fn remove(&mut self, other: Anchor)
cctk and winit only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Anchor)
Available on crate features cctk and winit only.
pub fn toggle(&mut self, other: Anchor)
cctk and winit only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Anchor, value: bool)
Available on crate features cctk and winit only.
pub fn set(&mut self, other: Anchor, value: bool)
cctk and winit only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Anchor) -> Anchor
Available on crate features cctk and winit only.
pub const fn intersection(self, other: Anchor) -> Anchor
cctk and winit only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Anchor) -> Anchor
Available on crate features cctk and winit only.
pub const fn union(self, other: Anchor) -> Anchor
cctk and winit only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Anchor) -> Anchor
Available on crate features cctk and winit only.
pub const fn difference(self, other: Anchor) -> Anchor
cctk and winit only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Anchor) -> Anchor
Available on crate features cctk and winit only.
pub const fn symmetric_difference(self, other: Anchor) -> Anchor
cctk and winit only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Anchor
Available on crate features cctk and winit only.
pub const fn complement(self) -> Anchor
cctk and winit only.The bitwise negation (!) of the bits in self, truncating the result.
impl Anchor
impl Anchor
pub const fn iter(&self) -> Iter<Anchor>
Available on crate features cctk and winit only.
pub const fn iter(&self) -> Iter<Anchor>
cctk and winit only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Anchor>
Available on crate features cctk and winit only.
pub const fn iter_names(&self) -> IterNames<Anchor>
cctk and winit only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.